@@ -2,6 +2,7 @@ class DocumentMeta:
     def __init__(
         self,
         level,
+        file_tree_mount_folder,
         document_filename_base,
         input_doc_full_path,
         input_doc_dir_rel_path,
@@ -9,6 +10,7 @@ class DocumentMeta:
         output_document_dir_rel_path,
     ):
         self.level = level
+        self.file_tree_mount_folder = file_tree_mount_folder
         self.document_filename_base = document_filename_base
         self.input_doc_full_path = input_doc_full_path
         self.input_doc_rel_path = input_doc_dir_rel_path
