@@ -33,7 +33,7 @@ class SourceFileViewHTMLGenerator:
         with open(source_file.full_path) as f:
             source_file_lines = f.readlines()
 
-        markup_renderer = MarkupRenderer()
+        markup_renderer = MarkupRenderer.create("RST")
 
         lexer = None
         if source_file.is_python_file():
@@ -80,8 +80,12 @@ class SourceFileViewHTMLGenerator:
                 replacement_line = source_line[
                     : pragma.reqs_objs[0].ng_source_column - 1
                 ]
+                replacement_line = (
+                    replacement_line.rstrip("/").rstrip("[").rstrip()
+                )
             pygmented_source_file_lines[pragma_line - 1] = (
                 replacement_line,
+                "",
                 pragma,
             )
 
